@@ -23,7 +23,7 @@
 #   This specific module is licensed under the Perl Artistic License.
 #
 #
-#   $Id: File.pm,v 1.18 2005/03/25 13:19:41 fredo Exp $
+#   $Id: File.pm,v 1.19 2005/06/02 12:59:43 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Basic::PDF::File;
@@ -293,7 +293,7 @@ sub open
         $self->{' fname'} = $fname;
     }
     $fh->read($buf, 255);
-    if ($buf !~ m/^\%pdf\-1\.(\d)\s*$cr/moi)
+    if ($buf !~ m/^\%pdf\-1\.(\d)\s*/moi)
     { die "$fname not a PDF file version 1.x"; }
     else
     { $self->{' Version'} = $1; }
