@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Content.pm,v 1.34 2005/03/15 02:20:46 fredo Exp $
+#   $Id: Content.pm,v 1.36 2005/05/29 09:48:46 fredo Exp $
 #
 #=======================================================================
 
@@ -47,7 +47,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Basic::PDF::Dict);
     
-    ( $VERSION ) = '$Revision: 1.34 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/15 02:20:46 $
+    ( $VERSION ) = '$Revision: 1.36 $' =~ /Revision: (\S+)\s/; # $Date: 2005/05/29 09:48:46 $
 
 }
 
@@ -1180,7 +1180,7 @@ sub image
 
 =item $gfx->formimage $imgobj, $x, $y
 
-B<Please Note:> *TODO*
+Places the X-Object (or XO-Form) at x/y with optional scale.
 
 =cut
 
@@ -1333,6 +1333,50 @@ sub textstate
     return(%state);
 }
 
+sub textstate2 
+{
+    my $self=shift @_;
+    my %state;
+    if(scalar @_) 
+    {
+        %state=@_;
+        foreach my $k (qw[ charspace hspace wordspace lead rise render ]) 
+        {
+            next unless($state{$k});
+            if($self->{" $k"} ne $state{$k})
+            {
+                eval ' $self->'.$k.'($state{$k}); ';
+            }
+        }
+        if($state{font} && $state{fontsize}) 
+        {
+            if($self->{" font"} ne $state{font} || $self->{" fontsize"} ne $state{fontsize})
+            {
+                $self->font($state{font},$state{fontsize});
+            }
+        }
+        if($state{fillcolor}) 
+        {
+            $self->fillcolor(@{$state{fillcolor}});
+        }
+        if($state{strokecolor}) 
+        {
+            $self->strokecolor(@{$state{strokecolor}});
+        }
+        %state=();
+    } 
+    else 
+    {
+        foreach my $k (qw[ font fontsize charspace hspace wordspace lead rise render ]) 
+        {
+            $state{$k}=$self->{" $k"};
+        }
+        $state{fillcolor}=[@{$self->{" fillcolor"}}];
+        $state{strokecolor}=[@{$self->{" strokecolor"}}];
+    }
+    return(%state);
+}
+
 =item ($tx,$ty) = $txt->textpos
 
 Gets the current estimated text position.
@@ -2106,6 +2150,12 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Content.pm,v $
+    Revision 1.36  2005/05/29 09:48:46  fredo
+    added conditional textstate2 method
+
+    Revision 1.35  2003/04/09 11:12:13  fredo
+    documented form-image
+
     Revision 1.34  2005/03/15 02:20:46  fredo
     added metadata stubs
 
